#!/bin/bash

# Installed directory
TRANS_DIR=./

# Set maximum Java heap size
DEFAULT_MAX_HEAP=128m

# Cleaner's main class
# Don't change.
CLEANER=ddbj.cleaner.app.Main

# Create temporary directory
unset tmpdir

function rmTmpdir {
  [[ -d "$tmpdir" ]] && rm -r $tmpdir
}

trap rmTmpdir EXIT
trap 'trap - EXIT; rmTmpdir; exit -1' HUP INT QUIT TERM

basepath=$(basename $0)
timestamp=$(date +%Y%m%d%H%M%S)
tmpdir=$(mktemp -dt "$basepath.$timestamp.XXXXXX")

# Usage
printUsage() {
        _myself=$1
        echo "Usage: $_myself [-x annotation file] [-s fasta file] [-e error message file] [-o amino acid sequence file] [-t alignment file] [-M maximum heap size]"
        echo "  -x : Annotation File"
        echo "  -s : FASTA-formatted File"
        echo "  -e : Error Message File (default:stdout)"
        echo "  -o : Amino Acid Sequence File (default:not output)"
        echo "  -t : Alignment File (default:not output)"
        echo "  -M : The size of maximum Java heap (default:${DEFAULT_MAX_HEAP})"
}

while getopts x:s:e:o:t:M: opt
do
        case $opt in
        x) ann=$OPTARG;;
        s) seq=$OPTARG;;
        e) err=$OPTARG;;
        o) ami=$OPTARG;;
        t) alt=$OPTARG;;
        M) mxh=$OPTARG;;
        \?) printUsage $0
                exit 1;;
        esac
done

heap=${mxh:-${DEFAULT_MAX_HEAP}}

# Cleaner's options
options=""
if [ ${ann:-notAnn} != "notAnn" ]
then
        tmpann=$tmpdir/$(basename ${ann:-notAnn})
        tmpanncln="$tmpann.cln"
        cp $ann $tmpann
        options="-x$tmpann"
fi
if [ ${seq:-notSeq} != "notSeq" ]
then
        tmpseq=$tmpdir/$(basename ${seq:-notSeq})
        tmpseqcln="$tmpseq.cln"
        cp $seq $tmpseq
        options="$options -s$tmpseq"
fi
cleanerlog=$tmpdir/cleaner.log
cleanererr=$tmpdir/cleaner.err

# Execution Cleaner
java -Xmx$heap -classpath $TRANS_DIR/jar/cleaner.jar $CLEANER $options >$cleanerlog 2>$cleanererr
RETVAL=$?

if [ $RETVAL -gt 2 ]
then
        echo "Cleaner has error."
        cat $cleanererr
        exit $RETVAL
fi

# transChecker's options
options=""
if [ ${ann:-notAnn} != "notAnn" ]
then
        options="-x $tmpanncln"
fi
if [ ${seq:-notSeq} != "notSeq" ]
then
        options="$options -s $tmpseqcln"
fi
if [ ${err:-notErr} != "notErr" ]
then
        options="$options -e $err"
fi
if [ ${ami:-notAmi} != "notAmi" ]
then
        options="$options -o $ami"
fi
if [ ${alt:-notAlt} != "notAlt" ]
then
        options="$options -t $alt"
fi

# Execution Command
# Don't change.
java -Xmx$heap -jar $TRANS_DIR/jar/transChecker.jar $options

RETVAL=$?

exit $RETVAL
#EOF
